@@ -1,9 +1,9 @@
 import inspect
-from typing import Callable, Set
+from typing import Callable, Iterable
 
 
 def delegate(
-    delegatee: Callable, *, kwonly: bool = True, delegate_docstring: bool = False, ignore: Set[str] = set()
+    delegatee: Callable, *, kwonly: bool = True, delegate_docstring: bool = False, ignore: Iterable[str] = ()
 ) -> Callable:
     """
     A decorator function that adds the parameters of a delegatee function to a delegator function,
@@ -19,10 +19,11 @@ def delegate(
                         The default value is True.
     :param delegate_docstring: A boolean value indicating whether the docstring of delegatee should be used as the docstring of the delegator function.
                         The default value is True.
-    :param ignore: A set of strings containing the names of the parameters of delegatee that should be ignored.
-                        The default value is an empty set.
+    :param ignore: An iterable of strings containing the names of the parameters of delegatee that should be ignored.
+                        The default value is an empty tuple.
     :return: The decorator function that modifies the delegator function.
     """
+    ignore = set(ignore)
     # Retrieve the parameter information of delegatee and filter out the ignored parameters.
     delegatee_params = list(inspect.signature(delegatee).parameters.values())
     delegatee_params = [param for param in delegatee_params if param.name not in ignore]
